@@ -20,6 +20,8 @@
 
 int main(int argc, char *argv[])
 {
+    QCoreApplication::setApplicationName("Pineapple Pictures");
+    QCoreApplication::setApplicationVersion(PPIC_VERSION_STRING);
     QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Settings::instance()->hiDpiScaleFactorBehavior());
 
     QApplication a(argc, argv);
@@ -35,18 +37,25 @@ int main(int argc, char *argv[])
     qmDir = QT_STRINGIFY(QM_FILE_INSTALL_DIR);
 #endif
     if (translator.load(QLocale(), QLatin1String("PineapplePictures"), QLatin1String("_"), qmDir)) {
-        a.installTranslator(&translator);
+        QCoreApplication::installTranslator(&translator);
     }
-    a.setApplicationName("Pineapple Pictures");
-    a.setApplicationDisplayName(QCoreApplication::translate("main", "Pineapple Pictures"));
 
+    QGuiApplication::setApplicationDisplayName(QCoreApplication::translate("main", "Pineapple Pictures"));
+
+    // commandline options
+    QCommandLineOption supportedImageFormats(QStringLiteral("supported-image-formats"), QCoreApplication::translate("main", "List supported image format suffixes, and quit program."));
     // parse commandline arguments
     QCommandLineParser parser;
+    parser.addOption(supportedImageFormats);
     parser.addPositionalArgument("File list", QCoreApplication::translate("main", "File list."));
     parser.addHelpOption();
-
     parser.process(a);
 
+    if (parser.isSet(supportedImageFormats)) {
+        fputs(qPrintable(MainWindow::supportedImageFormats().join(QChar('\n'))), stdout);
+        ::exit(EXIT_SUCCESS);
+    }
+
     MainWindow w;
     w.show();
 
@@ -59,5 +68,5 @@ int main(int argc, char *argv[])
 
     w.initWindowSize();
 
-    return a.exec();
+    return QApplication::exec();
 }
